@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef HEADERTEST_H
-#define HEADERTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -42,4 +41,3 @@ private Q_SLOTS:
     void noAbstractHeaders();
 };
 
-#endif
