@@ -1,19 +1,7 @@
 /*
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #undef QT_USE_FAST_CONCATENATION
@@ -144,7 +132,7 @@ void UtilTest::testAddQuotes_data()
     QTest::newRow("") << QByteArray("Lastname, Firstname")
                       << QByteArray("\"Lastname, Firstname\"") << false;
     QTest::newRow("") << QByteArray("John \"the hacker\" Smith")
-                      << QByteArray("\"John \\\"the hacker\\\" Smith\"") << false;
+                      << QByteArray(R"("John \"the hacker\" Smith")") << false;
 
     // Test the whole thing on strings as well, for one example
     QString string(QLatin1String("John \"the hacker\" Smith"));
